#pragma once

using namespace std ;

#include <complex>
#include <fstream>
#include <iostream>

// define this to add the temperature dependance of the partition sums
// The value of the macro is the HITRAN Reference temperature (K) for the partition sums
#define USE_QOFT 296

/** flag which input format is used in the ASCII files,
* one of http://www.hitran.com, http://spec.jpl.nasa.gov/ line or http://cfa-www.harvard.edu/firs/sao92.html
* @since 2010-06-10 GEISA-09
*/
enum catalog { HITRAN , SPECJPL , CFAWWW, JCP111, GEISA, GEISA_09 } ;

/** Maximum number of bytes per GEISA 2009 input line (Fortran total 252), which is followed by \n or \r\n, then \0
* In case of providing space for input data, this is to be considered larger than HITRANLL
*/
#define GEISALL 255

/** A line transition with line strength and vacuum wavelength.
@author Richard J. Mathar
*/
class transition {
public:

	/** vacuum wavelength  [mu]
	*/
	double micron ;

	/** unitless oscillator strength
	*/
	double f ;

	/** circular frequency [Hz]
	*/
	double omega0 ;

	/** wavenumber [1/cm]
	*/
	double waven ;

	/** line widths [wavenumber per atm]. Gamma broadened air.
	*/
	double width ;

	/** line widths [wavenumber per atm]. self broadening.
	*/
	double width_s ;

	/** line strength [1/cm / mole/cm^2]
	*/
	double strength ;

	/** squared dipole moment in HITRAN2000 [Debye^2]
	* @since HITRAN2004 Einstein A coefficient
	*/
	double dipole ;

	/** position/energy of the lower state [1/cm]
	*/
	double lowsta ;

	/** HITRAN molecule number. A value of zero is used to indicate
	* non-initialized (quasi invalid) molecular species.
	*/
	int molec ;

	/** HITRAN isotope number
	*/
	int isot ;

	transition(int molno=0) ;


#ifdef __GNUC__
	transition (istringstream & in, catalog &cat) ;
#else
	transition (istream & in, catalog &cat) ;
#endif

#ifdef USE_QOFT
	void Qsum(const double T) ;
#endif

	complex<double> Lorentz(const double omega) const ;

	complex<double> LorentzPrime(const double omega) const ;


private:
} ;
